===================================
Main entrypoint to generate results
===================================

.. automodule:: abed.results.main
    :members:
    :undoc-members:
    :show-inheritance:
